@@ -1,3 +1,6 @@
+import os
+
+
 def tree_to_pdf(file_name, path=''):
     """
     转换决策树到pdf文件
@@ -26,6 +29,6 @@ def tree_to_pdf(file_name, path=''):
         file_path = os.path.splitext(file_name)[0] + '.pdf'
 
     str_exec = 'dot -Tpdf ' + file_name + ' -o ' + file_path  # 决策树转pdf命令
-    print(str_exec)
+    # print(str_exec)
     result = os.popen(str_exec)
     return result
